// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/wyatt_ui_kit.dart';

/// {@template wyatt_theme_extensions}
/// Wyatt UI Kit theme extensions
///
/// This class is used to provide the theme extensions for the Wyatt UI Kit.
/// {@endtemplate}
class WyattThemeExtensions extends ThemeExtensionProvider {
  /// {@macro wyatt_theme_extensions}
  const WyattThemeExtensions() : super();

  /// Wyatt UI Kit, light theme extensions
  static List<ThemeExtension<dynamic>> light({ThemeData? theme}) => [
        // Cards
        CardThemeExtensionImpl.light(theme: theme),
        // Loader
        LoaderThemeExtensionImpl.light(theme: theme),
        // RichTextBuilder
        RichTextBuilderThemeExtensionImpl.light(theme: theme),
        // Buttons
        FileSelectionButtonThemeExtensionImpl.light(theme: theme),
        FlatButtonThemeExtensionImpl.light(theme: theme),
        SimpleIconButtonThemeExtensionImpl.light(theme: theme),
        SymbolButtonThemeExtensionImpl.light(theme: theme),
        // TextInput
        TextInputThemeExtensionImpl.light(theme: theme),
        // TopBar
        TopBarThemeExtensionImpl.light(theme: theme),
      ];

  /// Wyatt UI Kit, dark theme extensions
  static List<ThemeExtension<dynamic>> dark({ThemeData? theme}) => [
        // Cards
        CardThemeExtensionImpl.dark(theme: theme),
        // Loader
        LoaderThemeExtensionImpl.dark(theme: theme),
        // RichTextBuilder
        RichTextBuilderThemeExtensionImpl.dark(theme: theme),
        // Buttons
        FileSelectionButtonThemeExtensionImpl.dark(theme: theme),
        FlatButtonThemeExtensionImpl.dark(theme: theme),
        SimpleIconButtonThemeExtensionImpl.dark(theme: theme),
        SymbolButtonThemeExtensionImpl.dark(theme: theme),
        // TextInput
        TextInputThemeExtensionImpl.dark(theme: theme),
        // TopBar
        TopBarThemeExtensionImpl.dark(theme: theme),
      ];

  @override
  List<ThemeExtension<dynamic>> getThemeExtensionsFor(ThemeData theme) =>
      theme.brightness == Brightness.light
          ? light(theme: theme)
          : dark(theme: theme);
}
